%define anolis_release 1

%global githubname QATzip
%global libqatzip_soversion 3

Name:           qatzip
Version:        1.1.2
Release:        %{anolis_release}%{?dist}
Summary:        Intel QuickAssist Technology (QAT) QATzip Library
License:        BSD
URL:            https://github.com/intel/%{githubname}
Source0:        https://github.com/intel/%{githubname}/archive/v%{version}.tar.gz

Patch1000: 1001-update-requirements-of-qat-and-udma.patch
Patch1001: 1002-QATZIP-change-configure.patch
Patch1002: 1003-qaeMemAllocNUMA-change-to-4096-align.patch
Patch1003: 1004-qzmem-remove-use-udma-instead.patch
Patch1004: 1005-remove-g_strm_buff_list.patch

BuildRequires:  gcc >= 4.8.5 autoconf automake libtool make openssl-devel
BuildRequires:  zlib-devel >= 1.2.7 lz4-devel udma-devel intel-QAT20-devel

# The purpose of the package is to support hardware that only exists on x86_64 platforms
ExclusiveArch:  x86_64

%description
Intel QATzip is a software library designed to provide hardware-assisted
compression and decompression acceleration for data processing applications.
It works in conjunction with Intel QuickAssist Technology (QAT) hardware,
which is a specialized hardware accelerator for cryptographic and compression
workloads. QATzip supports a variety of compression algorithms, including GZIP,
DEFLATE, and LZ77. These algorithms can be used to reduce the size of data,
improve network and storage efficiency, and increase data transfer rates. 
The library provides an API that enables developers to integrate the compression
and decompression features into their applications easily. QATzip is often used
in cloud computing, big data, and network applications that require fast data
processing, low latency, and efficient data transfer. For example, it can be used
to compress data before sending it over a network, reducing the bandwidth required
and improving the response time. It can also be used to compress data before storing
it, reducing the storage requirements and improving the retrieval time. In summary,
Intel QATzip is a powerful software library that provides hardware-accelerated
compression and decompression capabilities to improve the performance, efficiency,
and throughput of data processing applications.

%package        libs
Summary:        Libraries for the qatzip package

%description    libs
This package contains libraries for applications to use
the QATzip APIs.

%package static
Summary: Provides the static lib for the qatzip package
Requires: %{name} = %{version}-%{release}

%description static
This package contains libraries for applications to use
the QATzip APIs.

%package        devel
Summary:        Development components for the libqatzip package
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
This package contains headers and libraries required to build
applications that use the QATzip APIs.

%package 	doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{githubname}-%{version} -p1

%build
%set_build_flags

autoreconf -ivf
export ICP_ROOT=%{_includedir}/qat
%configure \
    --enable-symbol

%make_build

%install
%make_install
rm -vf %{buildroot}%{_mandir}/*.pdf


%files
%license LICENSE*
%{_mandir}/man1/qzip.1*
%{_bindir}/qzip

%files libs
%license LICENSE*
%{_libdir}/libqatzip.so.%{libqatzip_soversion}*

%files static
%{_libdir}/libqatzip.a
/usr/lib64/libqatzip.la


%files devel
%{_includedir}/qatzip.h
%{_libdir}/libqatzip.so
%{_libdir}/pkgconfig/qatzip.pc
%doc docs/QATzip-man.pdf

%files doc
%doc docs/QATzip-man.pdf
%doc README.md

%changelog
* Thu Sep 07 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.1.2-1
- update version to 1.1.2
- change qatzip to use udma

* Mon Apr 10 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.9-2
- Update some defination

* Thu Oct 13 2022 happy_orange <songnannan@linux.alibaba.com> - 1.0.9-1
- Init pacakge from upstream
